#[repr(C)]pub struct DeviceGetBtiByIdResponse {
pub bti: Bti,
}Fields
bti: BtiTrait Implementations
Sourceimpl Debug for DeviceGetBtiByIdResponse
impl Debug for DeviceGetBtiByIdResponse
Sourceimpl<___E> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBtiByIdResponse>, ___E> for DeviceGetBtiByIdResponse
impl<___E> EncodeOption<Box<'static, DeviceGetBtiByIdResponse>, ___E> for DeviceGetBtiByIdResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBtiByIdResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBtiByIdResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetBtiByIdResponse> for DeviceGetBtiByIdResponse
impl FromWire<DeviceGetBtiByIdResponse> for DeviceGetBtiByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiByIdResponse) -> Self
fn from_wire(wire: DeviceGetBtiByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetBtiByIdResponse
impl PartialEq for DeviceGetBtiByIdResponse
Sourcefn eq(&self, other: &DeviceGetBtiByIdResponse) -> bool
fn eq(&self, other: &DeviceGetBtiByIdResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetBtiByIdResponse