#[repr(C)]pub struct DeviceGetBtiByNameResponse {
pub bti: Bti,
}Fields
bti: BtiTrait Implementations
Sourceimpl Debug for DeviceGetBtiByNameResponse
impl Debug for DeviceGetBtiByNameResponse
Sourceimpl<___E> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetBtiByNameResponse>, ___E> for DeviceGetBtiByNameResponse
impl<___E> EncodeOption<Box<'static, DeviceGetBtiByNameResponse>, ___E> for DeviceGetBtiByNameResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetBtiByNameResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetBtiByNameResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetBtiByNameResponse> for DeviceGetBtiByNameResponse
impl FromWire<DeviceGetBtiByNameResponse> for DeviceGetBtiByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiByNameResponse) -> Self
fn from_wire(wire: DeviceGetBtiByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetBtiByNameResponse
impl PartialEq for DeviceGetBtiByNameResponse
Sourcefn eq(&self, other: &DeviceGetBtiByNameResponse) -> bool
fn eq(&self, other: &DeviceGetBtiByNameResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetBtiByNameResponse