#[repr(C)]pub struct DeviceGetInterruptByIdResponse {
pub irq: Interrupt,
}Fields
irq: InterruptTrait Implementations
Sourceimpl<___E> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetInterruptByIdResponse>, ___E> for DeviceGetInterruptByIdResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptByIdResponse: Encode<DeviceGetInterruptByIdResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetInterruptByIdResponse>, ___E> for DeviceGetInterruptByIdResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptByIdResponse: Encode<DeviceGetInterruptByIdResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInterruptByIdResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInterruptByIdResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetInterruptByIdResponse> for DeviceGetInterruptByIdResponse
impl FromWire<DeviceGetInterruptByIdResponse> for DeviceGetInterruptByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptByIdResponse) -> Self
fn from_wire(wire: DeviceGetInterruptByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetInterruptByIdResponse
impl PartialEq for DeviceGetInterruptByIdResponse
Sourcefn eq(&self, other: &DeviceGetInterruptByIdResponse) -> bool
fn eq(&self, other: &DeviceGetInterruptByIdResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetInterruptByIdResponse