#[repr(C)]pub struct DeviceGetInterruptByNameResponse {
pub irq: Interrupt,
}Fields
irq: InterruptTrait Implementations
Sourceimpl<___E> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetInterruptByNameResponse>, ___E> for DeviceGetInterruptByNameResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptByNameResponse: Encode<DeviceGetInterruptByNameResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetInterruptByNameResponse>, ___E> for DeviceGetInterruptByNameResponsewhere
___E: Encoder + ?Sized,
DeviceGetInterruptByNameResponse: Encode<DeviceGetInterruptByNameResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetInterruptByNameResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetInterruptByNameResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetInterruptByNameResponse> for DeviceGetInterruptByNameResponse
impl FromWire<DeviceGetInterruptByNameResponse> for DeviceGetInterruptByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptByNameResponse) -> Self
fn from_wire(wire: DeviceGetInterruptByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetInterruptByNameResponse
impl PartialEq for DeviceGetInterruptByNameResponse
Sourcefn eq(&self, other: &DeviceGetInterruptByNameResponse) -> bool
fn eq(&self, other: &DeviceGetInterruptByNameResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetInterruptByNameResponse