#[repr(C)]pub struct DeviceGetSmcByIdResponse {
pub smc: Resource,
}Fields
smc: ResourceTrait Implementations
Sourceimpl Debug for DeviceGetSmcByIdResponse
impl Debug for DeviceGetSmcByIdResponse
Sourceimpl<___E> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetSmcByIdResponse>, ___E> for DeviceGetSmcByIdResponse
impl<___E> EncodeOption<Box<'static, DeviceGetSmcByIdResponse>, ___E> for DeviceGetSmcByIdResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSmcByIdResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetSmcByIdResponse> for DeviceGetSmcByIdResponse
impl FromWire<DeviceGetSmcByIdResponse> for DeviceGetSmcByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetSmcByIdResponse) -> Self
fn from_wire(wire: DeviceGetSmcByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetSmcByIdResponse
impl PartialEq for DeviceGetSmcByIdResponse
Sourcefn eq(&self, other: &DeviceGetSmcByIdResponse) -> bool
fn eq(&self, other: &DeviceGetSmcByIdResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetSmcByIdResponse