#[repr(C)]pub struct DeviceGetSmcByNameResponse {
pub smc: Resource,
}Fields
smc: ResourceTrait Implementations
Sourceimpl Debug for DeviceGetSmcByNameResponse
impl Debug for DeviceGetSmcByNameResponse
Sourceimpl<___E> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetSmcByNameResponse>, ___E> for DeviceGetSmcByNameResponse
impl<___E> EncodeOption<Box<'static, DeviceGetSmcByNameResponse>, ___E> for DeviceGetSmcByNameResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetSmcByNameResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetSmcByNameResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetSmcByNameResponse> for DeviceGetSmcByNameResponse
impl FromWire<DeviceGetSmcByNameResponse> for DeviceGetSmcByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetSmcByNameResponse) -> Self
fn from_wire(wire: DeviceGetSmcByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for DeviceGetSmcByNameResponse
impl PartialEq for DeviceGetSmcByNameResponse
Sourcefn eq(&self, other: &DeviceGetSmcByNameResponse) -> bool
fn eq(&self, other: &DeviceGetSmcByNameResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceGetSmcByNameResponse