pub struct DeviceGetMetadataRequest {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Clone for DeviceGetMetadataRequest
impl Clone for DeviceGetMetadataRequest
Sourcefn clone(&self) -> DeviceGetMetadataRequest
fn clone(&self) -> DeviceGetMetadataRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetMetadataRequest
impl Debug for DeviceGetMetadataRequest
Sourceimpl<'a, ___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetMetadataRequest<'static>>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetMetadataRequest: Encode<DeviceGetMetadataRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetMetadataRequest<'static>>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: Encoder + ?Sized,
&'a DeviceGetMetadataRequest: Encode<DeviceGetMetadataRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a DeviceGetMetadataRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMetadataRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceGetMetadataRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMetadataRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetMetadataRequest<'static>>, ___E> for DeviceGetMetadataRequestwhere
___E: Encoder + ?Sized,
DeviceGetMetadataRequest: Encode<DeviceGetMetadataRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetMetadataRequest<'static>>, ___E> for DeviceGetMetadataRequestwhere
___E: Encoder + ?Sized,
DeviceGetMetadataRequest: Encode<DeviceGetMetadataRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<DeviceGetMetadataRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetMetadataRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceGetMetadataRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetMetadataRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
impl<'de> FromWire<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
Sourcefn from_wire(wire: DeviceGetMetadataRequest<'de>) -> DeviceGetMetadataRequest
fn from_wire(wire: DeviceGetMetadataRequest<'de>) -> DeviceGetMetadataRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
impl<'de> FromWireRef<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
Sourcefn from_wire_ref(
wire: &DeviceGetMetadataRequest<'de>,
) -> DeviceGetMetadataRequest
fn from_wire_ref( wire: &DeviceGetMetadataRequest<'de>, ) -> DeviceGetMetadataRequest
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetMetadataRequest
impl Hash for DeviceGetMetadataRequest
Sourceimpl Ord for DeviceGetMetadataRequest
impl Ord for DeviceGetMetadataRequest
Sourcefn cmp(&self, other: &DeviceGetMetadataRequest) -> Ordering
fn cmp(&self, other: &DeviceGetMetadataRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetMetadataRequest
impl PartialEq for DeviceGetMetadataRequest
Sourcefn eq(&self, other: &DeviceGetMetadataRequest) -> bool
fn eq(&self, other: &DeviceGetMetadataRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetMetadataRequest
impl PartialOrd for DeviceGetMetadataRequest
impl Eq for DeviceGetMetadataRequest
impl StructuralPartialEq for DeviceGetMetadataRequest