#[repr(C)]pub struct DeviceGetBtiByIdResponse {
pub bti: Bti,
}Expand description
The wire type corresponding to DeviceGetBtiByIdResponse.
Fields
bti: BtiTrait Implementations
Sourceimpl Constrained for DeviceGetBtiByIdResponse
impl Constrained for DeviceGetBtiByIdResponse
Sourceimpl Debug for DeviceGetBtiByIdResponse
impl Debug for DeviceGetBtiByIdResponse
Sourceimpl<___D> Decode<___D> for DeviceGetBtiByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetBtiByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
impl<___E, T0> Encode<DeviceGetBtiByIdResponse, ___E> for DeviceGetBtiByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBtiByIdResponse> for DeviceGetBtiByIdResponse
impl FromWire<DeviceGetBtiByIdResponse> for DeviceGetBtiByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiByIdResponse) -> Self
fn from_wire(wire: DeviceGetBtiByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetBtiByIdResponse
impl IntoNatural for DeviceGetBtiByIdResponse
Sourcetype Natural = DeviceGetBtiByIdResponse
type Natural = DeviceGetBtiByIdResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBtiByIdResponse
impl Wire for DeviceGetBtiByIdResponse
Sourcetype Narrowed<'de> = DeviceGetBtiByIdResponse
type Narrowed<'de> = DeviceGetBtiByIdResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.