#[repr(C)]pub struct DeviceGetBtiByNameResponse {
pub bti: Bti,
}Expand description
The wire type corresponding to DeviceGetBtiByNameResponse.
Fields
bti: BtiTrait Implementations
Sourceimpl Constrained for DeviceGetBtiByNameResponse
impl Constrained for DeviceGetBtiByNameResponse
Sourceimpl Debug for DeviceGetBtiByNameResponse
impl Debug for DeviceGetBtiByNameResponse
Sourceimpl<___D> Decode<___D> for DeviceGetBtiByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetBtiByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetBtiByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
impl<___E, T0> Encode<DeviceGetBtiByNameResponse, ___E> for DeviceGetBtiByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Bti, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetBtiByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetBtiByNameResponse> for DeviceGetBtiByNameResponse
impl FromWire<DeviceGetBtiByNameResponse> for DeviceGetBtiByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetBtiByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetBtiByNameResponse) -> Self
fn from_wire(wire: DeviceGetBtiByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetBtiByNameResponse
impl IntoNatural for DeviceGetBtiByNameResponse
Sourcetype Natural = DeviceGetBtiByNameResponse
type Natural = DeviceGetBtiByNameResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetBtiByNameResponse
impl Wire for DeviceGetBtiByNameResponse
Sourcetype Narrowed<'de> = DeviceGetBtiByNameResponse
type Narrowed<'de> = DeviceGetBtiByNameResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.