#[repr(C)]pub struct DeviceGetInterruptByIdResponse {
pub irq: Interrupt,
}Expand description
The wire type corresponding to DeviceGetInterruptByIdResponse.
Fields
irq: InterruptTrait Implementations
Sourceimpl Constrained for DeviceGetInterruptByIdResponse
impl Constrained for DeviceGetInterruptByIdResponse
Sourceimpl<___D> Decode<___D> for DeviceGetInterruptByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetInterruptByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
impl<___E, T0> Encode<DeviceGetInterruptByIdResponse, ___E> for DeviceGetInterruptByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetInterruptByIdResponse> for DeviceGetInterruptByIdResponse
impl FromWire<DeviceGetInterruptByIdResponse> for DeviceGetInterruptByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptByIdResponse) -> Self
fn from_wire(wire: DeviceGetInterruptByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetInterruptByIdResponse
impl IntoNatural for DeviceGetInterruptByIdResponse
Sourcetype Natural = DeviceGetInterruptByIdResponse
type Natural = DeviceGetInterruptByIdResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetInterruptByIdResponse
impl Wire for DeviceGetInterruptByIdResponse
Sourcetype Narrowed<'de> = DeviceGetInterruptByIdResponse
type Narrowed<'de> = DeviceGetInterruptByIdResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.