#[repr(C)]pub struct DeviceGetInterruptByNameResponse {
pub irq: Interrupt,
}Expand description
The wire type corresponding to DeviceGetInterruptByNameResponse.
Fields
irq: InterruptTrait Implementations
Sourceimpl Constrained for DeviceGetInterruptByNameResponse
impl Constrained for DeviceGetInterruptByNameResponse
Sourceimpl<___D> Decode<___D> for DeviceGetInterruptByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetInterruptByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetInterruptByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
impl<___E, T0> Encode<DeviceGetInterruptByNameResponse, ___E> for DeviceGetInterruptByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetInterruptByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetInterruptByNameResponse> for DeviceGetInterruptByNameResponse
impl FromWire<DeviceGetInterruptByNameResponse> for DeviceGetInterruptByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetInterruptByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetInterruptByNameResponse) -> Self
fn from_wire(wire: DeviceGetInterruptByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetInterruptByNameResponse
impl IntoNatural for DeviceGetInterruptByNameResponse
Sourcetype Natural = DeviceGetInterruptByNameResponse
type Natural = DeviceGetInterruptByNameResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetInterruptByNameResponse
impl Wire for DeviceGetInterruptByNameResponse
Sourcetype Narrowed<'de> = DeviceGetInterruptByNameResponse
type Narrowed<'de> = DeviceGetInterruptByNameResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.