#[repr(C)]pub struct DeviceGetMetadataRequest<'de> {
pub id: String<'de>,
}Expand description
The wire type corresponding to DeviceGetMetadataRequest.
Fields
id: String<'de>Trait Implementations
Sourceimpl Constrained for DeviceGetMetadataRequest<'_>
impl Constrained for DeviceGetMetadataRequest<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetMetadataRequest<'_>>,
_: <DeviceGetMetadataRequest<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetMetadataRequest<'_>>, _: <DeviceGetMetadataRequest<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for DeviceGetMetadataRequest<'de>
impl<'de> Debug for DeviceGetMetadataRequest<'de>
Sourceimpl<'de, ___D> Decode<___D> for DeviceGetMetadataRequest<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for DeviceGetMetadataRequest<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for &'a DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequest<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
impl<___E, T0> Encode<DeviceGetMetadataRequest<'static>, ___E> for DeviceGetMetadataRequest<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<String<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
impl<'de> FromWire<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
Sourcefn from_wire(wire: DeviceGetMetadataRequest<'de>) -> DeviceGetMetadataRequest
fn from_wire(wire: DeviceGetMetadataRequest<'de>) -> DeviceGetMetadataRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
impl<'de> FromWireRef<DeviceGetMetadataRequest<'de>> for DeviceGetMetadataRequest
Sourcefn from_wire_ref(
wire: &DeviceGetMetadataRequest<'de>,
) -> DeviceGetMetadataRequest
fn from_wire_ref( wire: &DeviceGetMetadataRequest<'de>, ) -> DeviceGetMetadataRequest
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for DeviceGetMetadataRequest<'de>
impl<'de> IntoNatural for DeviceGetMetadataRequest<'de>
Sourcetype Natural = DeviceGetMetadataRequest
type Natural = DeviceGetMetadataRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetMetadataRequest<'static>
impl Wire for DeviceGetMetadataRequest<'static>
Sourcetype Narrowed<'de> = DeviceGetMetadataRequest<'de>
type Narrowed<'de> = DeviceGetMetadataRequest<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetMetadataRequest<'static>>)
Writes zeroes to the padding for this type, if any.