#[repr(C)]pub struct DeviceGetMmioByIdRequest {
pub index: Uint32,
}Expand description
The wire type corresponding to DeviceGetMmioByIdRequest.
Fields
index: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetMmioByIdRequest
impl Clone for DeviceGetMmioByIdRequest
Sourcefn clone(&self) -> DeviceGetMmioByIdRequest
fn clone(&self) -> DeviceGetMmioByIdRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetMmioByIdRequest
impl Constrained for DeviceGetMmioByIdRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetMmioByIdRequest>,
_: <DeviceGetMmioByIdRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetMmioByIdRequest>, _: <DeviceGetMmioByIdRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for DeviceGetMmioByIdRequest
impl Debug for DeviceGetMmioByIdRequest
Sourceimpl<___D> Decode<___D> for DeviceGetMmioByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetMmioByIdRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetMmioByIdRequest, ___E> for &'a DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetMmioByIdRequest, ___E> for &'a DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, DeviceGetMmioByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, DeviceGetMmioByIdRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetMmioByIdRequest, ___E> for DeviceGetMmioByIdRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
impl FromWire<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, DeviceGetMmioByIdRequest>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetMmioByIdRequest, DeviceGetMmioByIdRequest>
Sourcefn from_wire(wire: DeviceGetMmioByIdRequest) -> DeviceGetMmioByIdRequest
fn from_wire(wire: DeviceGetMmioByIdRequest) -> DeviceGetMmioByIdRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
impl FromWireRef<DeviceGetMmioByIdRequest> for DeviceGetMmioByIdRequest
Sourcefn from_wire_ref(wire: &DeviceGetMmioByIdRequest) -> DeviceGetMmioByIdRequest
fn from_wire_ref(wire: &DeviceGetMmioByIdRequest) -> DeviceGetMmioByIdRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetMmioByIdRequest
impl IntoNatural for DeviceGetMmioByIdRequest
Sourcetype Natural = DeviceGetMmioByIdRequest
type Natural = DeviceGetMmioByIdRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetMmioByIdRequest
impl Wire for DeviceGetMmioByIdRequest
Sourcetype Narrowed<'de> = DeviceGetMmioByIdRequest
type Narrowed<'de> = DeviceGetMmioByIdRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetMmioByIdRequest>)
Writes zeroes to the padding for this type, if any.