#[repr(C)]pub struct DeviceGetSmcByIdResponse {
pub smc: Resource,
}Expand description
The wire type corresponding to DeviceGetSmcByIdResponse.
Fields
smc: ResourceTrait Implementations
Sourceimpl Constrained for DeviceGetSmcByIdResponse
impl Constrained for DeviceGetSmcByIdResponse
Sourceimpl Debug for DeviceGetSmcByIdResponse
impl Debug for DeviceGetSmcByIdResponse
Sourceimpl<___D> Decode<___D> for DeviceGetSmcByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetSmcByIdResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByIdResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Resource, ___E>,
impl<___E, T0> Encode<DeviceGetSmcByIdResponse, ___E> for DeviceGetSmcByIdResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Resource, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByIdResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetSmcByIdResponse> for DeviceGetSmcByIdResponse
impl FromWire<DeviceGetSmcByIdResponse> for DeviceGetSmcByIdResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByIdResponse, Self>
Sourcefn from_wire(wire: DeviceGetSmcByIdResponse) -> Self
fn from_wire(wire: DeviceGetSmcByIdResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetSmcByIdResponse
impl IntoNatural for DeviceGetSmcByIdResponse
Sourcetype Natural = DeviceGetSmcByIdResponse
type Natural = DeviceGetSmcByIdResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetSmcByIdResponse
impl Wire for DeviceGetSmcByIdResponse
Sourcetype Narrowed<'de> = DeviceGetSmcByIdResponse
type Narrowed<'de> = DeviceGetSmcByIdResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.