#[repr(C)]pub struct DeviceGetSmcByNameResponse {
pub smc: Resource,
}Expand description
The wire type corresponding to DeviceGetSmcByNameResponse.
Fields
smc: ResourceTrait Implementations
Sourceimpl Constrained for DeviceGetSmcByNameResponse
impl Constrained for DeviceGetSmcByNameResponse
Sourceimpl Debug for DeviceGetSmcByNameResponse
impl Debug for DeviceGetSmcByNameResponse
Sourceimpl<___D> Decode<___D> for DeviceGetSmcByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetSmcByNameResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByNameResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSmcByNameResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Resource, ___E>,
impl<___E, T0> Encode<DeviceGetSmcByNameResponse, ___E> for DeviceGetSmcByNameResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Resource, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSmcByNameResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetSmcByNameResponse> for DeviceGetSmcByNameResponse
impl FromWire<DeviceGetSmcByNameResponse> for DeviceGetSmcByNameResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByNameResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSmcByNameResponse, Self>
Sourcefn from_wire(wire: DeviceGetSmcByNameResponse) -> Self
fn from_wire(wire: DeviceGetSmcByNameResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetSmcByNameResponse
impl IntoNatural for DeviceGetSmcByNameResponse
Sourcetype Natural = DeviceGetSmcByNameResponse
type Natural = DeviceGetSmcByNameResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetSmcByNameResponse
impl Wire for DeviceGetSmcByNameResponse
Sourcetype Narrowed<'de> = DeviceGetSmcByNameResponse
type Narrowed<'de> = DeviceGetSmcByNameResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.